@@ -14,7 +14,7 @@ def plot_scores(output_dir='',cyrange=False):
 			pdb = line[1][:[pos for pos, char in enumerate(line[1]) if char == '_'][-1]] # accounts for "_" appearing in structure name
 			model = int(line[1].split('_')[-1])
 			shifts = line[3]
-			shift_perc = int(line[5])
+			shift_perc = float(line[5])
 			corr_score = float(line[9])
 			rmsd_score = float(line[13])
 			if cyrange:
